jsonlines

package
v0.3.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 27, 2025 License: Apache-2.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var ErrEmptyContent = errors.New("content is empty")

Functions

func IsJSONLines

func IsJSONLines(content string) error

IsJSONLines returns true if the content is a JSON Lines. JSON Lines is a text format where each line is a valid JSON object. Read more at https://jsonlines.org.

Types

This section is empty.

Jump to